@@ -4,37 +4,35 @@ package Kubectl::CLIWrapper {
   use IPC::Open3;
   use Kubectl::CLIWrapper::Result;
 
-  our $VERSION = '0.04';
+  our $VERSION = '0.05';
 
   has kubeconfig => (is => 'ro', isa => 'Str', predicate => 'has_kubeconfig');
   has kubectl => (is => 'ro', isa => 'Str', default => 'kubectl');
   has namespace => (is => 'ro', isa => 'Str', predicate => 'has_namespace');
   has password => (is => 'ro', isa => 'Str', predicate => 'has_password');
   has server => (is => 'ro', isa => 'Str', predicate => 'has_server');
-  has token => (is => 'ro', isa => 'Str', predicate => 'has_token');
+  has token => (is => 'ro', isa => 'Str|CodeRef', predicate => 'has_token');
   has username => (is => 'ro', isa => 'Str', predicate => 'has_username');
 
   has insecure_tls => (is => 'ro', isa => 'Bool', default => 0);
 
-  has kube_options => (
-        is      => 'ro',
-        isa     => 'ArrayRef[Str]',
-        lazy    => 1,
-        builder => 'build_options',
-  );
-
-  sub build_options {
+  sub kube_options {
     my $self = shift;
     my %options = ();
 
     $options{server}     = $self->server     if $self->has_server;
     $options{username}   = $self->username   if $self->has_username;
     $options{password}   = $self->password   if $self->has_password;
-    $options{token}      = $self->token      if $self->has_token;
     $options{namespace}  = $self->namespace  if $self->has_namespace;
     $options{kubeconfig} = $self->kubeconfig if $self->has_kubeconfig;
     $options{'insecure-skip-tls-verify'} = 'true' if $self->insecure_tls;
 
+    if ($self->has_token) {
+      $options{token} = ref($self->token) eq 'CODE'
+        ? &{$self->token}()
+        : $self->token;
+    }
+
     return [ map { "--$_=$options{ $_ }" } keys %options ];
   }
 
@@ -167,7 +165,9 @@ The password for Basic Authentication
 
 =head2 token
 
-The Bearer token for authentication
+The Bearer token for authentication. If it's a scalar, that value will be used. If it's
+a coderef (sub {}), it will be invoked each time kubectl is called and it's return value
+used as the value of the --token option
 
 =head2 insecure_tls
 
@@ -211,7 +211,9 @@ L<Net::Kubernetes>
 
 waterkip: adding the possiblity to set a kubeconfig file
 
-ureesoriano: fix for token attribute being ignored
+ureesoriano:
+ - fix for token attribute being ignored
+ - dynamic generation of the "token" command-line option 
 
 =head1 AUTHOR
 
